@@ -3,19 +3,17 @@ BEGIN {
   $MooseX::LazyRequire::Meta::Attribute::Trait::LazyRequire::AUTHORITY = 'cpan:FLORA';
 }
 {
-  $MooseX::LazyRequire::Meta::Attribute::Trait::LazyRequire::VERSION = '0.08';
+  $MooseX::LazyRequire::Meta::Attribute::Trait::LazyRequire::VERSION = '0.09';
 }
 # ABSTRACT: Attribute trait to make getters fail on unset attributes
 
 use Moose::Role;
 use Carp qw/cluck/;
-use MooseX::Types::Moose qw/Bool/;
 use namespace::autoclean;
 
 has lazy_required => (
     is       => 'ro',
-    isa      => Bool,
-    required => 1,
+    isa      => 'Bool',
     default  => 0,
 );
 
@@ -29,10 +27,12 @@ after _process_options => sub {
 
     return unless $options->{lazy_required};
 
+    # lazy_required + default or builder doesn't make sense because if there
+    # is a default/builder, the reader will always be able to return a value.
     Moose->throw_error(
         "You may not use both a builder or a default and lazy_required for one attribute ($name)",
         data => $options,
-    ) if $options->{builder};
+    ) if $options->{builder} or $options->{default};
 
     $options->{ lazy     } = 1;
     $options->{ required } = 1;
@@ -49,6 +49,7 @@ sub register_implementation { 'MooseX::LazyRequire::Meta::Attribute::Trait::Lazy
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -79,4 +80,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
